import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { BrowserStorageService } from 'src/app/modules/shared/services/browser-storage/browser-storage.service';
import { LoginModel } from '../../models/login.model';
import { RegisterModel } from '../../models/register.model';
import { TokenResponse } from '../../models/token.response';
import { UserModel } from '../../models/user.model';
import { AuthTokenService } from '../../../shared/services/auth/auth-token.service';

@Injectable()
export class AuthService {
    constructor(
        private http: HttpClient,
        private authTokenService: AuthTokenService,
        ) {
    }

    createAccount(data: RegisterModel): Observable<UserModel> {
        return this.http.post<UserModel>('/api/register', data);
    }

    login(data: LoginModel): Observable<TokenResponse> {
        const out = new Subject<TokenResponse>();
        this.http.post<TokenResponse>('/api/login', {
            username: data.email,
            password: data.password,
        }).subscribe(data => {
            this.authTokenService.setToken(data.token);
            out.next(data);
        });
        return out;
    }

    logout() {
        this.authTokenService.removeToken();
    }
}
